# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext_lazy as _
from jmb.core.admin.options import ExtendibleModelAdmin
from jmb.showcase.models import Item, Category
from image_cropping import ImageCroppingMixin
from jmb.showcase.forms import ItemAdminForm


class CategoryAdmin(ExtendibleModelAdmin):
    search_fields = ('title',)
    list_display = (
        'ordering', 'title', 'slug', 'get_edit_icon', 'get_delete_icon',
    )
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (None, {
            'fields': (
                'ordering', 'title', 'slug'
            )
        }),
    )
    save_on_top = True
    prepopulated_fields = {"slug": ("title",)}


class ItemAdmin(ImageCroppingMixin, ExtendibleModelAdmin):
    search_fields = ('title',)
    form = ItemAdminForm
    advanced_search_fields = (
        ('title__icontains', 'content__icontains'),
        ('tale__icontains',),
        ('publication_date__lte', 'publication_date__gte'),
        ('link_type',),
        ('categories',),
    )
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_("Ordering"), {
            'fields': ('ordering',),
            'classes': ('collapse',)
        }),
        (None, {
            'fields': (
                'status', 'tale', 'title', 'slug', 'categories',
            )
        }),
        (_('Content'), {
            'fields': (
                'author', 'source', 'content', 'language', 'image', 'rollover_image',
                'rollover_small_image', 'small_image', 'large_image', 'icon', 'file', 'link', 'internal_link',
                'linkedin_link', 'twitter_link', 'publication_date'
            )
        }),
        (_('Behavior'), {
            'fields': (
                'active_class', 'show_image', 'show_link', 'link_type'
            )
        }),
        (_('seo admin'), {
            'fields': (
                'meta_description', 'meta_keywords',
                'page_title',),
        }),
    )
    list_display = (
        'get_status_icon', 'ordering', 'title', 'slug',
        'tale', 'publication_date', 'get_categories',
        'get_edit_icon', 'get_delete_icon',
    )
    save_on_top = True
    prepopulated_fields = {"slug": ("title",)}
    filter_horizontal = ('categories',)


admin.site.register(Category, CategoryAdmin)
admin.site.register(Item, ItemAdmin)
